pub struct Global {Show 17 fields
pub name: String,
pub path: PathBuf,
pub autoboot: bool,
pub bootargs: Option<String>,
pub pool: Option<String>,
pub limitpriv: BTreeSet<String>,
pub brand: String,
pub hostid: Option<u32>,
pub ip_type: IpType,
pub cpu_shares: Option<u32>,
pub max_lwps: Option<u32>,
pub max_message_ids: Option<u32>,
pub max_semaphore_ids: Option<u32>,
pub max_shared_memory_ids: Option<u32>,
pub max_shared_memory: Option<u64>,
pub scheduling_class: Option<String>,
pub fs_allowed: BTreeSet<String>,
}Fields
name: StringThe name of the zone.
path: PathBufThe path to the zone’s filesystem.
autoboot: boolBoolean indicating if the zone should be automatically booted at system boot.
Requires the zone service to be enabled to operate.
bootargs: Option<String>Arguments passed to the zone bootup.
pool: Option<String>The name of the resoure pool bound to this zone.
Incompatible with the dedicated-cpu resource.
limitpriv: BTreeSet<String>The maximum set of privileges any process in this zone can obtain.
brand: StringThe zone’s brand type.
hostid: Option<u32>32-bit host identifier.
ip_type: IpTypeThe way in which IP is shared with the global zone.
The number of Fair Share Scheduler (FSS) shares to allocate to this zone.
This property is incompatible with the dedicated-cpu resource.
max_lwps: Option<u32>The maximum number of LWPs (lightweight processes) available to this zone.
max_message_ids: Option<u32>The maximum number of message queue IDs allowed for this zone.
max_semaphore_ids: Option<u32>The maximum number of semaphore IDs allowed for this zone.
The maximum number of shared memory IDs allowed for this zone.
The maximum amount of shared memory allowed for this zone, in bytes.
scheduling_class: Option<String>Specifies the scheduling class used for processes running in a zone.
If unspecified, it is inferred as follows:
- If the
cpu-sharesproperty has been set, FSS is used. - If
cpu-sharesis not set and thepoolproperty references a pool that has a default scheduling class, that class is used. - Otherwise, the system’s default scheduling class is used.
fs_allowed: BTreeSet<String>A comma-separated list of additional filesystems that may be mounted within the zone (for example, “ufs,pcfs”).